.. _utils:

Utils
=====

Other support functions are documented bellow:

.. currentmodule:: hostphot.utils
.. autofunction:: trim_images
.. autofunction:: get_survey_filters
.. autofunction:: check_survey_validity
.. autofunction:: check_filters_validity
.. autofunction:: extract_filters
.. autofunction:: clean_sn_dir
